@@ -2,6 +2,8 @@ import braintree
 import warnings
 from decimal import Decimal
 from braintree.add_on import AddOn
+from braintree.apple_pay_card import ApplePayCard
+from braintree.coinbase_account import CoinbaseAccount
 from braintree.disbursement_detail import DisbursementDetail
 from braintree.dispute import Dispute
 from braintree.discount import Discount
@@ -14,12 +16,13 @@ from braintree.configuration import Configuration
 from braintree.credit_card import CreditCard
 from braintree.customer import Customer
 from braintree.paypal_account import PayPalAccount
-from braintree.sepa_bank_account import SEPABankAccount
+from braintree.europe_bank_account import EuropeBankAccount
 from braintree.subscription_details import SubscriptionDetails
 from braintree.resource_collection import ResourceCollection
 from braintree.transparent_redirect import TransparentRedirect
 from braintree.exceptions.not_found_error import NotFoundError
 from braintree.descriptor import Descriptor
+from braintree.risk_data import RiskData
 
 class Transaction(Resource):
     """
@@ -72,7 +75,7 @@ class Transaction(Resource):
         print(result.transaction.amount)
         print(result.transaction.order_id)
 
-    For more information on Transactions, see https://www.braintreepayments.com/docs/python/transactions/create
+    For more information on Transactions, see https://developers.braintreepayments.com/python/reference/request/transaction/sale
 
     """
 
@@ -100,12 +103,15 @@ class Transaction(Resource):
         * braintree.Transaction.GatewayRejectionReason.AvsAndCvv
         * braintree.Transaction.GatewayRejectionReason.Cvv
         * braintree.Transaction.GatewayRejectionReason.Duplicate
+        * braintree.Transaction.GatewayRejectionReason.Fraud
+        * braintree.Transaction.GatewayRejectionReason.ThreeDSecure
         """
         Avs          = "avs"
         AvsAndCvv    = "avs_and_cvv"
         Cvv          = "cvv"
         Duplicate    = "duplicate"
         Fraud        = "fraud"
+        ThreeDSecure = "three_d_secure"
         Unrecognized = "unrecognized"
 
     class Source(object):
@@ -175,6 +181,10 @@ class Transaction(Resource):
         Credit = "credit"
         Sale = "sale"
 
+    class IndustryType(object):
+        Lodging = "lodging"
+        TravelAndCruise = "travel_cruise"
+
     @staticmethod
     def clone_transaction(transaction_id, params):
         return Configuration.gateway().transaction.clone_transaction(transaction_id, params)
@@ -439,13 +449,33 @@ class Transaction(Resource):
                     "store_in_vault_on_success",
                     "store_shipping_address_in_vault",
                     "submit_for_settlement",
-                    "venmo_sdk_session"
+                    "venmo_sdk_session",
+                    "payee_email",
+                    {
+                        "paypal": [
+                            "payee_email",
+                            "custom_field"
+                        ],
+                        "three_d_secure": [
+                            "required"
+                        ],
+                    },
                 ]
             },
             {"custom_fields": ["__any_key__"]},
             {"descriptor": ["name", "phone", "url"]},
-            {"paypal_account": ["payee_email"]}
-        ]
+            {"paypal_account": ["payee_email"]},
+            {"industry":
+                [
+                    "industry_type",
+                    {
+                        "data": [
+                            "folio_number", "check_in_date", "check_out_date", "departure_date", "lodging_check_in_date", "lodging_check_out_date", "travel_package", "lodging_name", "room_rate"
+                            ]
+                        }
+                    ]
+                }
+            ]
 
     def __init__(self, gateway, attributes):
         if "refund_id" in attributes:
@@ -465,8 +495,12 @@ class Transaction(Resource):
             self.credit_card_details = CreditCard(gateway, attributes.pop("credit_card"))
         if "paypal" in attributes:
             self.paypal_details = PayPalAccount(gateway, attributes.pop("paypal"))
-        if "sepa_bank_account" in attributes:
-            self.sepa_bank_account_details = SEPABankAccount(gateway, attributes.pop("sepa_bank_account"))
+        if "europe_bank_account" in attributes:
+            self.europe_bank_account_details = EuropeBankAccount(gateway, attributes.pop("europe_bank_account"))
+        if "apple_pay" in attributes:
+            self.apple_pay_details = ApplePayCard(gateway, attributes.pop("apple_pay"))
+        if "coinbase_account" in attributes:
+            self.coinbase_details = CoinbaseAccount(gateway, attributes.pop("coinbase_account"))
         if "customer" in attributes:
             self.customer_details = Customer(gateway, attributes.pop("customer"))
         if "shipping" in attributes:
@@ -488,6 +522,11 @@ class Transaction(Resource):
         if "payment_instrument_type" in attributes:
             self.payment_instrument_type = attributes["payment_instrument_type"]
 
+        if "risk_data" in attributes:
+            self.risk_data = RiskData(attributes["risk_data"])
+        else:
+            self.risk_data = None
+
     @property
     def refund_id(self):
         warnings.warn("Please use Transaction.refund_ids instead", DeprecationWarning)
