@@ -110,17 +110,17 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertNotEqual(None, found_credit_card)
         self.assertEquals(found_credit_card.token, created_credit_card.token)
 
-    def test_create_with_sepa_bank_account_nonce(self):
+    def test_create_with_europe_bank_account_nonce(self):
         config = Configuration.instantiate()
         customer_id = Customer.create().customer.id
-        token = TestHelper.generate_decoded_client_token({"customer_id": customer_id, "sepa_mandate_type": SEPABankAccount.MandateType.Business})
+        token = TestHelper.generate_decoded_client_token({"customer_id": customer_id, "sepa_mandate_type": EuropeBankAccount.MandateType.Business})
         authorization_fingerprint = json.loads(token)["authorizationFingerprint"]
         client_api =  ClientApiHttp(config, {
             "authorization_fingerprint": authorization_fingerprint,
             "shared_customer_identifier": "fake_identifier",
             "shared_customer_identifier_type": "testing"
         })
-        nonce = client_api.get_sepa_bank_account_nonce({
+        nonce = client_api.get_europe_bank_account_nonce({
             "locale": "de-DE",
             "bic": "DEUTDEFF",
             "iban": "DE89370400440532013000",
@@ -140,7 +140,37 @@ class TestPaymentMethod(unittest.TestCase):
 
         self.assertNotEqual(found_bank_account, None)
         self.assertEquals(found_bank_account.bic, "DEUTDEFF")
-        self.assertEquals(found_bank_account.__class__, SEPABankAccount)
+        self.assertEquals(found_bank_account.__class__, EuropeBankAccount)
+
+    def test_create_with_fake_apple_pay_nonce(self):
+        customer_id = Customer.create().customer.id
+        result = PaymentMethod.create({
+            "customer_id": customer_id,
+            "payment_method_nonce": Nonces.ApplePayMasterCard
+        })
+
+        self.assertTrue(result.is_success)
+        apple_pay_card = result.payment_method
+        self.assertIsInstance(apple_pay_card, ApplePayCard)
+        self.assertNotEqual(apple_pay_card.token, None)
+        self.assertEqual(ApplePayCard.CardType.MasterCard, apple_pay_card.card_type)
+        self.assertEqual("MasterCard 0017", apple_pay_card.payment_instrument_name)
+        self.assertTrue(apple_pay_card.default)
+        self.assertIn("apple_pay", apple_pay_card.image_url)
+        self.assertTrue(int(apple_pay_card.expiration_month) > 0)
+        self.assertTrue(int(apple_pay_card.expiration_year) > 0)
+
+    def test_create_with_abstract_payment_method_nonce(self):
+        customer_id = Customer.create().customer.id
+        result = PaymentMethod.create({
+            "customer_id": customer_id,
+            "payment_method_nonce": Nonces.AbstractTransactable
+        })
+
+        self.assertTrue(result.is_success)
+        payment_method = result.payment_method
+        self.assertNotEqual(None, payment_method)
+        self.assertNotEqual(None, payment_method.token)
 
     def test_create_respects_verify_card_and_verification_merchant_account_id_when_outside_nonce(self):
         config = Configuration.instantiate()
@@ -335,7 +365,7 @@ class TestPaymentMethod(unittest.TestCase):
     def test_create_does_not_return_an_error_if_credit_card_options_are_present_for_paypal_nonce(self):
         customer_id = Customer.create().customer.id
         original_token = "paypal-account-" + str(int(time.time()))
-        nonce = Nonces.nonce_for_paypal_account({
+        nonce = TestHelper.nonce_for_paypal_account({
             "consent_code": "consent-code",
             "token": original_token
         })
@@ -353,7 +383,7 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertTrue(result.is_success)
 
     def test_create_for_paypal_ignores_passed_billing_address_id(self):
-        nonce = Nonces.nonce_for_paypal_account({
+        nonce = TestHelper.nonce_for_paypal_account({
             "consent_code": "consent-code"
         })
         customer_id = Customer.create().customer.id
@@ -372,7 +402,7 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertFalse(found_paypal_account == None)
 
     def test_create_for_paypal_ignores_passed_billing_address_params(self):
-        nonce = Nonces.nonce_for_paypal_account({
+        nonce = TestHelper.nonce_for_paypal_account({
             "consent_code": "PAYPAL_CONSENT_CODE"
         })
         customer_id = Customer.create().customer.id
@@ -392,6 +422,18 @@ class TestPaymentMethod(unittest.TestCase):
         found_paypal_account = PayPalAccount.find(token)
         self.assertFalse(found_paypal_account == None)
 
+    def test_find_returns_an_abstract_payment_method(self):
+        customer_id = Customer.create().customer.id
+        result = PaymentMethod.create({
+            "customer_id": customer_id,
+            "payment_method_nonce": Nonces.AbstractTransactable
+        })
+        self.assertTrue(result.is_success)
+
+        found_payment_method = PaymentMethod.find(result.payment_method.token)
+        self.assertNotEqual(None, found_payment_method)
+        self.assertEqual(result.payment_method.token, found_payment_method.token)
+
     def test_find_returns_a_paypal_account(self):
         customer_id = Customer.create().customer.id
         result = PaymentMethod.create({
@@ -673,7 +715,7 @@ class TestPaymentMethod(unittest.TestCase):
     def test_update_updates_a_paypal_accounts_token(self):
         customer_id = Customer.create().customer.id
         original_token = "paypal-account-" + str(int(time.time()))
-        nonce = Nonces.nonce_for_paypal_account({
+        nonce = TestHelper.nonce_for_paypal_account({
             "consent_code": "consent-code",
             "token": original_token
         })
@@ -702,7 +744,7 @@ class TestPaymentMethod(unittest.TestCase):
         })
         self.assertTrue(credit_card_result.is_success)
 
-        nonce = Nonces.nonce_for_paypal_account({
+        nonce = TestHelper.nonce_for_paypal_account({
             "consent_code": "consent-code"
         })
         original_token = PaymentMethod.create({
@@ -723,7 +765,7 @@ class TestPaymentMethod(unittest.TestCase):
         first_token = "paypal-account-" + str(randint(0,100000000))
         second_token = "paypal-account-" + str(randint(0,100000000))
 
-        first_nonce = Nonces.nonce_for_paypal_account({
+        first_nonce = TestHelper.nonce_for_paypal_account({
             "consent_code": "consent-code",
             "token": first_token
         })
@@ -732,7 +774,7 @@ class TestPaymentMethod(unittest.TestCase):
              "customer_id": customer_id
         })
 
-        second_nonce = Nonces.nonce_for_paypal_account({
+        second_nonce = TestHelper.nonce_for_paypal_account({
             "consent_code": "consent-code",
             "token": second_token
         })
