@@ -60,3 +60,14 @@ class TestCustomer(unittest.TestCase):
 
         self.assertEquals(customer.paypal_accounts[0].token, "token1")
         self.assertEquals(customer.paypal_accounts[1].token, "token2")
+
+    def test_initialize_sets_europe_bank_accounts(self):
+        customer = Customer("gateway", {
+            "europe_bank_accounts": [
+                {"token": "token1"},
+                {"token": "token2"}
+            ]
+        })
+
+        self.assertEquals(customer.europe_bank_accounts[0].token, "token1")
+        self.assertEquals(customer.europe_bank_accounts[1].token, "token2")
